SET client_encoding = 'WIN1251';

--  --

CREATE TABLE "Tepl"."PaternToPlcID"
(
  plc_id integer NOT NULL, --   ID  
  pat_id integer NOT NULL --   ID 
)
WITH (
  OIDS=FALSE
);
ALTER TABLE "Tepl"."PaternToPlcID"
  OWNER TO postgres;
COMMENT ON TABLE "Tepl"."PaternToPlcID"
  IS '     ';
COMMENT ON COLUMN "Tepl"."PaternToPlcID".plc_id IS '  ID  ';
COMMENT ON COLUMN "Tepl"."PaternToPlcID".pat_id IS '  ID ';

--   --

CREATE OR REPLACE FUNCTION "Tepl"."GetPatternsDB"()
  RETURNS TABLE(id integer, type_id integer, name text) AS
$BODY$BEGIN
  RETURN QUERY SELECT plc_table.pat_id AS "id", plc_table.typ_id AS "type_id", pat_table."Name" AS "name"
  FROM "Tepl"."PaternToPlc" plc_table
  LEFT JOIN "Tepl"."PaternRep_cnt" pat_table ON (plc_table.pat_id=pat_table.pat_id);
END;$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION "Tepl"."GetPatternsDB"()
  OWNER TO postgres;
  
CREATE OR REPLACE FUNCTION "Tepl"."GetPlaceUserPatterns"(IN place_id integer)
  RETURNS TABLE(id integer, name text) AS
$BODY$
BEGIN
  RETURN QUERY SELECT pat_table.pat_id AS "id", pat_table."Name" AS "name"
  FROM "Tepl"."PaternRep_cnt" pat_table
  LEFT JOIN "Tepl"."PaternToPlcID" ptp_table ON ptp_table.pat_id=pat_table.pat_id
  WHERE ($1=-1 OR ptp_table.plc_id = $1);
END;$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION "Tepl"."GetPlaceUserPatterns"(integer)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."GetPlaceUserPatterns"(integer) IS '      ';

CREATE OR REPLACE FUNCTION "Tepl"."UpdatePlaceUserPatterns"(place_id integer, pat_ids text)
  RETURNS boolean AS
$BODY$DECLARE
  pats INTEGER[];
  i INTEGER;
  n INTEGER;
BEGIN
  /*      */
  DELETE FROM "Tepl"."PaternToPlcID" WHERE "plc_id"=$1;
  /*  */
  pats = string_to_array($2, ',');
  n = array_upper(pats, 1);
  if (n > 0) then
    for i in 1..array_upper(pats, 1) loop
      INSERT INTO "Tepl"."PaternToPlcID"
        ("plc_id","pat_id")
      VALUES
        ($1, pats[i]);
    end loop;
  end if;
  return true;
END;$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 10;
ALTER FUNCTION "Tepl"."UpdatePlaceUserPatterns"(integer, text)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."UpdatePlaceUserPatterns"(integer, text) IS '    ';

--   --

DROP FUNCTION "Tepl"."DeletePatern"(integer);

CREATE OR REPLACE FUNCTION "Tepl"."DeletePatern"(ppat_id integer)
  RETURNS boolean AS
$BODY$
DECLARE

BEGIN
 /*     */
 DELETE FROM "Tepl"."ElToPR_Rep" Where "Tepl"."ElToPR_Rep"."pat_id"=$1; 
 DELETE From "Tepl"."ParamResPlcRep_cnt" Where "Tepl"."ParamResPlcRep_cnt"."pat_id"=$1; 
 DELETE From "Tepl"."PlaceRep" Where "Tepl"."PlaceRep"."pat_id"=$1;    
 DELETE From "Tepl"."GroupParRep" Where "pat_id"=$1;
 DELETE From "Tepl"."ParametrRep_cnt" Where "pat_id"=$1;
 DELETE From "Tepl"."FormulValueNode" Where "pat_id"=$1;
 DELETE From "Tepl"."InfoViewParametrrep" Where "pat_id"=$1;
 DELETE From "Tepl"."PaternRepGroupRelations" WHERE "pat_id"=$1;   
 
 /*     */
 DELETE From "Tepl"."PaternToPlc"  
 WHERE pat_id=$1;
 /*    */
 DELETE From "Tepl"."PaternToPlcID"  
 WHERE pat_id=$1;
                           
 /*  */
 Delete FROM "Tepl"."PaternRep_cnt" 
 Where "Tepl"."PaternRep_cnt"."pat_id"=$1;
 

/*   */
 Delete FROM "Tepl"."RangesToParamPatern" 
 Where "Tepl"."RangesToParamPatern"."pat_id"=$1;


 return true;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."DeletePatern"(integer)
  OWNER TO postgres;





DROP FUNCTION "Tepl"."DeletePlaces"(text);

CREATE OR REPLACE FUNCTION "Tepl"."DeletePlaces"(pplc_ids text)
  RETURNS boolean AS
$BODY$
DECLARE
 i integer;
 n integer;
 splace_id Text; 
 fdel boolean;    
 v text;
 pr_id text;
 plc "Tepl"."Places_cnt"%ROWTYPE; 
 pr "Tepl"."ParamResPlc_cnt"%ROWTYPE;    
 con "Tepl"."Connect_cnt"%ROWTYPE;   
 usp "Tepl"."USPD_cnt"%ROWTYPE;    
 plcs integer[];
BEGIN
   plcs="Tepl"."fArr"($1);
   FOR plc in SELECT * FROM "Tepl"."Places_cnt" Where "Tepl"."Places_cnt".place_id=any(plcs) Loop
      /*    */
      splace_id:=plc.plc_id;
      fdel:= "Tepl"."DeletePlaces"(splace_id);
    end Loop;   
    
    /*     */   
   pr_id='';
    FOR pr in SELECT * FROM "Tepl"."ParamResPlc_cnt" Where "Tepl"."ParamResPlc_cnt".plc_id=any(plcs) Loop      
      v:=pr."prp_id";
      pr_id:=pr_id||v||chr(3);
    end Loop;
    pr_id=pr_id||'-100'; 
    fdel:="Tepl"."DeleteParemResPlc"(pr_id); 
    
    /*  */
    Delete from "Tepl"."PropPlc_cnt" 
    Where "Tepl"."PropPlc_cnt"."plc_id"=any(plcs); 
    
    /*   */
    FOR con in SELECT * FROM "Tepl"."Connect_cnt" Where "Tepl"."Connect_cnt".plc_id=any(plcs) Loop      
      fdel:="Tepl"."DeleteConnect"(con.Con_id);
    end Loop;
    /*   */                                          
    FOR usp in SELECT * FROM "Tepl"."USPD_cnt" Where "Tepl"."USPD_cnt".plc_id=any(plcs) Loop      
      fdel:="Tepl"."DeleteUspd"(usp.usp_id);
    end Loop;
  
    /*  */
    Delete from "Tepl"."Places_cnt" 
    Where "Tepl"."Places_cnt"."plc_id"=any(plcs); 

    /*     */
    Delete from "Tepl"."PaternToPlcID" 
    Where "Tepl"."PaternToPlcID"."plc_id"=any(plcs); 
    
  
  return true;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."DeletePlaces"(text)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."DeletePlaces"(text) IS ' ';
