SET client_encoding = 'WIN1251';
CREATE TABLE "Tepl"."AnalyticRanges" (
  "range_id" INTEGER NOT NULL, 
  "range_typ" INTEGER NOT NULL,
  "Name" TEXT, 
  "Minimum" DOUBLE PRECISION, 
  "Maximum" DOUBLE PRECISION, 
  "Contract" DOUBLE PRECISION
) WITH OIDS;

COMMENT ON TABLE "Tepl"."AnalyticRanges"
IS ' ';

COMMENT ON COLUMN "Tepl"."AnalyticRanges"."range_id"
IS 'id ';

COMMENT ON COLUMN "Tepl"."AnalyticRanges"."range_typ"
IS '  (0-, 1-, 2-)';

COMMENT ON COLUMN "Tepl"."AnalyticRanges"."Name"
IS ' ';

COMMENT ON COLUMN "Tepl"."AnalyticRanges"."Minimum"
IS '';

COMMENT ON COLUMN "Tepl"."AnalyticRanges"."Maximum"
IS '';

COMMENT ON COLUMN "Tepl"."AnalyticRanges"."Contract"
IS ' ';

------------------------------------------------------------------------------

CREATE TYPE "Tepl"."TAnalyticRange" AS (
  "range_id" INTEGER, 
  "range_typ" INTEGER,
  "Name" TEXT, 
  "Minimum" DOUBLE PRECISION, 
  "Maximum" DOUBLE PRECISION, 
  "Contract" DOUBLE PRECISION
);

COMMENT ON TYPE "Tepl"."TAnalyticRange"
IS ' ';

------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."GetAnalyticRanges" () RETURNS SETOF "Tepl"."TAnalyticRange" AS
$body$
SELECT 
  "Tepl"."AnalyticRanges"."range_id",
  "Tepl"."AnalyticRanges"."range_typ",
  "Tepl"."AnalyticRanges"."Name",
  "Tepl"."AnalyticRanges"."Minimum",
  "Tepl"."AnalyticRanges"."Maximum",
  "Tepl"."AnalyticRanges"."Contract"
FROM
  "Tepl"."AnalyticRanges"
$body$
LANGUAGE 'sql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;

COMMENT ON FUNCTION "Tepl"."GetAnalyticRanges"()
IS '   ';

------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."DeleteAnalyticRanges" (prange_id text) RETURNS "pg_catalog"."void" AS
$body$
DECLARE
 ranges integer[];
Begin
 ranges="Tepl"."fArr"($1);
 Delete From "Tepl"."AnalyticRanges"
 Where range_id=ANY(ranges);

 Delete From "Tepl"."RangesToParam" where  range_id=ANY(ranges);

end;
$body$
LANGUAGE 'plpgsql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;

COMMENT ON FUNCTION "Tepl"."DeleteAnalyticRanges"(prange_id text)
IS '  ';

------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."InsertAnalyticRanges" ("prange_typ" text, "pName" text, "pMinimum" text, "pMaximum" text, "pContract" text) RETURNS text AS
$body$
DECLARE
  ret text;
  types integer[];
  names text[];
  minimums double precision[];
  maximums double precision[];
  contracts double precision[];    
  i integer;
  n integer; 
  maxp integer; 
BEGIN
    ret:='{';
	maxp:=(SELECT  max("range_id") from "Tepl"."AnalyticRanges")+1;  
    IF maxp IS NULL THEN
		maxp := 1;
	END IF;
	
    types="Tepl"."fArr"($1);
    names="Tepl"."fArrText"($2);
    minimums="Tepl"."fArrDoublePressis"($3);
    maximums="Tepl"."fArrDoublePressis"($4); 
    contracts="Tepl"."fArrDoublePressis"($5);
    
	FOR i in 1..n Loop 
      INSERT INTO "Tepl"."AnalyticRanges"
      ("range_id", "range_typ", "Name", "Minimum", "Maximum", "Contract")
      Values
      (maxp, types[i], names[i], minimums[i], maximums[i], contracts[i]);
      ret=ret||maxp;
      if i<n then 
      	ret=ret||',';
      end if;
      maxp:=maxp+1;  
    end loop;
END;
$body$
LANGUAGE 'plpgsql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;
------------------------------------------------------------------------------

CREATE TABLE "Tepl"."RangesToParam" (
  "range_id" INTEGER NOT NULL, 
  "prp_id" INTEGER NOT NULL
) WITH OIDS;

------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."GetRangesForParam" (pprp_id integer) RETURNS text AS
$body$
DECLARE
  ret Text;
  i integer; 
  _count integer; 
  maxp integer := 1;
BEGIN
	_count := COUNT("range_id") FROM "Tepl"."RangesToParam" WHERE prp_id=$1;
	ret := '{';
	FOR i IN SELECT "range_id" FROM "Tepl"."RangesToParam" WHERE prp_id=$1 LOOP
		ret=ret||i;  
        IF maxp<_count THEN
	        ret=ret||',';
        END IF;
        maxp=maxp+1;    
    END LOOP;	
    ret = ret||'}'; 
    return ret;
END;
$body$
LANGUAGE 'plpgsql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;

------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION "Tepl"."DeleteParemResPlc" (pprp_id text) RETURNS boolean AS
$body$
DECLARE
 sens "Tepl"."Sensor_cnt"%ROWTYPE;
 delsen Text; 
 prs integer[];
BEGIN
  prs="Tepl"."fArr"($1);
  /*   */
  DELETE FROM "Tepl"."Arhiv_cnt"
  Where "pr_id"=ANY(prs);
  /*       */  
  DELETE FROM "Tepl"."DeviceContingencyArhiv_cnt"
  Where "pr_id"=ANY(prs);
  /*     */
  DELETE FROM "Tepl"."Task_cnt"
  Where "prp_id"=ANY(prs);                                                   
  /*     */
  DELETE FROM "Tepl"."TaskArhivUSPD_cnt"
  Where "prp_id"=ANY(prs);  
  /*      */
  Delete From "Tepl"."EventTab"
  Where "prp_id"=ANY(prs);
  /*      */
  DELETE FROM "Tepl"."PointRead"
  Where "prp_id"=ANY(prs);
  /*    */
  DELETE FROM "Tepl"."ParamResGroupRelations"
  Where "prp_id"=ANY(prs);  
  /*     */          
  FOR sens in Select * From "Tepl"."Sensor_cnt" where "prp_id"=ANY(prs) Loop
    Delete From "Tepl"."Sensor_Property"
    WHERE "s_id"=sens."s_id";    
  end Loop;
  /*     */    
  DELETE FROM "Tepl"."Sensor_cnt"
  Where "prp_id"=ANY(prs);
  
  Delete From "Tepl"."RangesToParam" where  prp_id=ANY(prs);
  
  /*  */
  Delete From "Tepl"."ParamResPlc_cnt"
  WHERE "prp_id"=ANY(prs); 
	
   return true;
END;
$body$
LANGUAGE 'plpgsql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;

COMMENT ON FUNCTION "Tepl"."DeleteParemResPlc"(pprp_id text)
IS '  ';

------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."DeleteRangeToParam" (pprp_id text) RETURNS boolean AS
$body$
DECLARE
  prps integer[];
BEGIN
  prps="Tepl"."fArr"($1);
  DELETE FROM "Tepl"."RangesToParam"
  Where "prp_id"=ANY(prps);
  return true;
 
END;
$body$
LANGUAGE 'plpgsql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;

COMMENT ON FUNCTION "Tepl"."DeleteRangeToParam"(pprp_id text)
IS '     ';

------------------------------------------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."InsertRangeToParam" (prange_id text, pprp_id text) RETURNS boolean AS
$body$
DECLARE
  i integer;
  n integer;
  maxp integer;
  range_ids integer[];
  prp_ids INTEGER[];
BEGIN
  range_ids="Tepl"."fArr"($1);
  n:=array_upper(range_ids,1);
  if n>0 THEN                
    prp_ids:="Tepl"."fArr"($2);

    FOR i in 1..n Loop     
       Insert into "Tepl"."RangesToParam" 
       ("range_id","prp_id") 
       Values
       (range_ids[i],prp_ids[i]); 
    end Loop;       
  end if;     
  return true;
END;
$body$
LANGUAGE 'plpgsql' VOLATILE CALLED ON NULL INPUT SECURITY INVOKER;

COMMENT ON FUNCTION "Tepl"."InsertRangeToParam" (prange_id text, pprp_id text) 
IS '     ';
------------------------------------------------------------------------------
