
SET client_encoding = 'UTF8';

CREATE TABLE "Tepl"."ActiveSessions"
(
  id serial NOT NULL,
  alive timestamp without time zone NOT NULL DEFAULT now(),
  session text NOT NULL,
  state integer NOT NULL DEFAULT 0,
  CONSTRAINT "ActiveSessions_pkey" PRIMARY KEY (id )
)
WITH (
  OIDS=FALSE
);
ALTER TABLE "Tepl"."ActiveSessions"
  OWNER TO postgres;
COMMENT ON TABLE "Tepl"."ActiveSessions"
  IS 'Хранит информацию о активных сессиях открытых конфигураторов';
COMMENT ON COLUMN "Tepl"."ActiveSessions".id IS 'Идентификатор сессии';
COMMENT ON COLUMN "Tepl"."ActiveSessions".alive IS 'Последнее время обновления';
COMMENT ON COLUMN "Tepl"."ActiveSessions".session IS 'Имя пользователя';
COMMENT ON COLUMN "Tepl"."ActiveSessions".state IS 'Маска состояния';

CREATE OR REPLACE FUNCTION "Tepl"."UpdateSession"(IN session_id integer, IN session_name text, IN session_state integer, OUT id integer, OUT name text, OUT state integer, OUT alive timestamp without time zone)
  RETURNS SETOF record AS
$BODY$
DECLARE
  i record;
BEGIN
  -- Удаляем старые записи (таймаут 15 секунд)
  DELETE FROM "Tepl"."ActiveSessions" tbl
  WHERE tbl.alive <= now() - interval '10 seconds';
  -- Обновляем показание
  IF session_id <= 0 THEN
    INSERT INTO "Tepl"."ActiveSessions"
    (session, state)
    VALUES
    (session_name, session_state);
    session_id = (SELECT MAX(tbl.id) as "id" FROM "Tepl"."ActiveSessions" tbl);
  ELSE
    UPDATE "Tepl"."ActiveSessions" tbl
    SET session = session_name, state = session_state, alive = now()
    WHERE tbl.id = session_id;
  END IF;
  -- Вывод результата
    -- Текущая сессия, только так, т.к. она может быть дропнута
  FOR i IN SELECT * 
           FROM "Tepl"."ActiveSessions" tbl
           WHERE tbl.id = session_id LOOP
    id = i.id;
    name = i.session;
    state = i.state;
    alive = i.alive;
    RETURN NEXT;
  END LOOP;
    -- Активная сессия
  FOR i IN SELECT *
           FROM "Tepl"."ActiveSessions" tbl
           ORDER BY tbl.id
           LIMIT 1 LOOP
    id = i.id;
    name = i.session;
    state = i.state;
    alive = i.alive;
    RETURN NEXT;
  END LOOP;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 2;
ALTER FUNCTION "Tepl"."UpdateSession"(integer, text, integer)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."UpdateSession"(integer, text, integer) IS 'Обновляет состояние сессии текущего клиента, клиент сразу отправляет свои данные, при этом если указан идентификатор меньше или равный 0, то запись будет добавлена, иначе будет обновлена по указанному идентификатору. Возвращает функция две строки, первая - информаци о текущей сессии, по факту нужна тольк для определения идентификатора и максимум для определения серверного времени, вторая строка - информация о активной сессии.';
