SET client_encoding = 'UTF8';

/* Новая колонка в таблицу соединений */

ALTER TABLE "Tepl"."Connect_cnt"
   ADD COLUMN mobile boolean NOT NULL DEFAULT FALSE;
COMMENT ON COLUMN "Tepl"."Connect_cnt".mobile IS 'Принадлежность к мобильному опросу';

/* Хранимка запроса соединений */

DROP FUNCTION "Tepl"."GetConnect_cnt"(integer);
CREATE OR REPLACE FUNCTION "Tepl"."GetConnect_cnt"(pplc_id integer)
  RETURNS TABLE(id integer, name text, comment text, type_id integer, parent_id integer, mobile boolean) AS
$BODY$
SELECT 
  connects.con_id AS id,
  connects."Name" AS name,        /* Имя соединения */
  connects."Comment" AS comment,  /* Комментарий для соединения */
  connects.typ_con_id AS type_id, /* id типа соединения */
  connects.plc_id AS parent_id,   /* Место установки(присутствия соединения) */
  connects.mobile AS mobile       /* Принадлежность к мобильному опросу */
FROM
  "Tepl"."Connect_cnt" connects
WHERE ($1 <= -1 OR connects.plc_id = $1) AND 
       connects.con_id >= 0 AND
       connects.uspd_id < 0  
ORDER BY connects.plc_id, connects.typ_con_id;
$BODY$
  LANGUAGE sql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION "Tepl"."GetConnect_cnt"(integer)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."GetConnect_cnt"(integer) IS 'Получение соединений установленных на объектах';

DROP FUNCTION "Tepl"."GetUSPDConnect_cnt"(integer);
CREATE OR REPLACE FUNCTION "Tepl"."GetUSPDConnect_cnt"(puspd_id integer)
  RETURNS TABLE(id integer, name text, comment text, type_id integer, parent_id integer, mobile boolean) AS
$BODY$
SELECT 
  connects.con_id AS id,
  connects."Name" AS name,        /* Имя соединения */
  connects."Comment" AS comment,  /* Комментарий для соединения */
  connects.typ_con_id AS type_id, /* id типа соединения */
  connects.plc_id AS parent_id,   /* Место установки(присутствия соединения) */
  connects.mobile AS mobile       /* Принадлежность к мобильному опросу */
FROM
  "Tepl"."Connect_cnt" connects
WHERE ($1 <= -1 OR connects.uspd_id = $1) AND 
       connects.con_id >= 0 
ORDER BY connects.plc_id, connects.typ_con_id;
$BODY$
  LANGUAGE sql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION "Tepl"."GetUSPDConnect_cnt"(integer)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."GetUSPDConnect_cnt"(integer) IS 'Получение соединений установленных на УСПД';

/* Хранимка вставки соединений */

DROP FUNCTION "Tepl"."InsertConnect"(text, text, integer, integer);
CREATE OR REPLACE FUNCTION "Tepl"."InsertConnect"(pname text, pcomment text, ptyp integer, pplc_id integer, mobile boolean)
  RETURNS integer AS
$BODY$
DECLARE
ret  INTEGER; 
BEGIN
  ret:=(Select max("con_id") from "Tepl"."Connect_cnt")+1; 
  IF ret IS NULL THEN
	ret := 1;
  END IF;
  insert INTO "Tepl"."Connect_cnt"
  (con_id,"Name","Comment",typ_con_id,plc_id,uspd_id,mobile)
  VALUES
  (ret,$1,$2,$3,$4,-1,$5);
  return ret;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."InsertConnect"(text, text, integer, integer, boolean)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."InsertConnect"(text, text, integer, integer, boolean) IS 'Вставка нового соединения на объект';

/* Хранимка обновления соединений */

DROP FUNCTION "Tepl"."UpdateConnect_cnt"(text, text, integer, integer, integer);
CREATE OR REPLACE FUNCTION "Tepl"."UpdateConnect_cnt"(pname text, pcomment text, ptyp integer, pplc_id integer, pcon_id integer, mobile boolean)
  RETURNS boolean AS
$BODY$
BEGIN
  UPDATE "Tepl"."Connect_cnt"
  set "Name"=$1, "Comment"=$2, typ_con_id=$3, plc_id=$4, mobile=$6
  Where con_id=$5;    
  return true;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."UpdateConnect_cnt"(text, text, integer, integer, integer, boolean)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."UpdateConnect_cnt"(text, text, integer, integer, integer, boolean) IS 'Изменение соединения на объекте

Внимание!!!
При изменении типа соединения необходимо дополнительно переделать свойства конфигураций!!!';
