SET client_encoding = 'UTF8';

CREATE TABLE "Tepl"."IoTcache" (  
  tr_id INTEGER NOT NULL,
  tr_addr TEXT NOT NULL,
  rcvr_id INTEGER NOT NULL,
  con_id INTEGER  NOT NULL,
  last_date TIMESTAMP(0) WITHOUT TIME ZONE
) 
WITH (oids = false);

COMMENT ON TABLE "Tepl"."IoTcache"
IS 'Кэш IoT передатчиков';

COMMENT ON COLUMN "Tepl"."IoTcache".tr_id
IS 'id передатчика';

COMMENT ON COLUMN "Tepl"."IoTcache".tr_addr
IS 'Адрес передатчика';

COMMENT ON COLUMN "Tepl"."IoTcache".rcvr_id
IS 'id приёмника';

COMMENT ON COLUMN "Tepl"."IoTcache".con_id
IS 'id соединения';

COMMENT ON COLUMN "Tepl"."IoTcache".last_date
IS 'дата последней посылки';

ALTER TABLE "Tepl"."IoTcache"
  OWNER TO postgres;
  
---------------------------------------------
CREATE OR REPLACE FUNCTION "Tepl"."GetIoTcache" (
  con_id integer
)
RETURNS TABLE (
  tr_id INTEGER,
  tr_addr TEXT,
  rcvr_id INTEGER,
  con_id INTEGER,
  last_date TIMESTAMP(0) WITHOUT TIME ZONE
) AS
$body$

SELECT 
*
 From  "Tepl"."IoTcache" WHERE ("Tepl"."IoTcache".con_id = $1)

$body$
LANGUAGE 'sql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
COST 100 ROWS 1000;

COMMENT ON FUNCTION "Tepl"."GetIoTcache"(con_id integer)
IS 'Возвращает кэш IoT передатчиков для соединения';

ALTER FUNCTION "Tepl"."GetIoTcache" (con_id integer)
  OWNER TO postgres;  
  
---------------------------------------------

CREATE OR REPLACE FUNCTION "Tepl"."InsertOrUpdateIoTcache" (
  pcon_id INTEGER,-- id соединения
  ptr_id text,-- id передатчиков
  ptr_addr text,-- адреса передатчиков
  prcvr_id text,-- id приёмников
  plast_date text-- даты последних посылок
)
RETURNS boolean AS
$body$
DECLARE
  i integer;
  n integer;
      
  con_ids INTEGER;	  
  tr_ids INTEGER[];  
  tr_addrs text[]; 
  rcvr_ids integer[];
  last_dates timestamp without time zone[];  
  act bool;
  
BEGIN
  con_ids = $1;
  tr_ids = "Tepl"."fArr"($2);
  n := array_upper(tr_ids, 1);   
   
  if (n > 0) THEN

--    tr_ids="Tepl"."fArr"($2);
    tr_addrs="Tepl"."fArrText"($3); 
	rcvr_ids="Tepl"."fArr"($4);
    last_dates="Tepl"."farrTime"($5);
       
    FOR i in 1..n Loop      

		DELETE FROM "Tepl"."IoTcache" WHERE "Tepl"."IoTcache".tr_id = tr_ids[i] AND
		"Tepl"."IoTcache".tr_addr = tr_addrs[i] AND
		"Tepl"."IoTcache".rcvr_id = rcvr_ids[i] AND
		"Tepl"."IoTcache".con_id = con_ids AND
		"Tepl"."IoTcache".last_date = last_dates[i];
		
		INSERT INTO "Tepl"."IoTcache" (tr_id, tr_addr, rcvr_id, con_id, last_date)
		VALUES (tr_ids[i], tr_addrs[i], rcvr_ids[i], con_ids, last_dates[i]);    

    end Loop;    
  end IF;         
  
    return TRUE;
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
COST 100;

COMMENT ON FUNCTION "Tepl"."InsertOrUpdateIoTcache" (pcon_id INTEGER, ptr_id text, ptr_addr text, prcvr_id text, plast_date text)
IS 'Вставка или обновление кэша IoT передатчиков';

ALTER FUNCTION "Tepl"."InsertOrUpdateIoTcache" (pcon_id INTEGER, ptr_id text, ptr_addr text, prcvr_id text, plast_date text)
  OWNER TO postgres;  