
SET client_encoding = 'UTF8';

-- Удаление старой таблицы кэша

DROP FUNCTION "Tepl"."GetIoTcache"(integer);
DROP FUNCTION "Tepl"."InsertOrUpdateIoTcache"(integer, text, text, text, text);

-- Обновление свойств типов прибора для указания признака IoT передатчика

UPDATE "Tepl"."TypeDevices" 
   SET  "AdditionInfo" = "AdditionInfo"&(~1) ;

UPDATE "Tepl"."TypeDevices" 
  SET  "AdditionInfo" = "AdditionInfo" | 1 
WHERE dev_typ_id = any(ARRAY[345,327,324,312]);

-- Таблица нового кэша

CREATE TABLE "Tepl"."IOT_reciver_cache"
(
  transiver_num integer,
  reciver_num integer,
  date_reciv timestamp without time zone,
  mess text
)
WITH (
  OIDS=TRUE
);
ALTER TABLE "Tepl"."IOT_reciver_cache"
  OWNER TO postgres;

-- Index: "Tepl"."IOT_reciver_cache_reciver_num_transiver_num_idx"

-- DROP INDEX "Tepl"."IOT_reciver_cache_reciver_num_transiver_num_idx";

CREATE INDEX "IOT_reciver_cache_reciver_num_transiver_num_idx"
  ON "Tepl"."IOT_reciver_cache"
  USING btree
  (reciver_num  NULLS FIRST, transiver_num  NULLS FIRST);

-- Index: "Tepl".transiv

-- DROP INDEX "Tepl".transiv;

CREATE INDEX transiv
  ON "Tepl"."IOT_reciver_cache"
  USING btree
  (transiver_num );

-- Удаление записей кэша

CREATE OR REPLACE FUNCTION "Tepl"."Clear_Iot_cache"(transiv text, reciv text, date_reciv text)
  RETURNS boolean AS
$BODY$
--Передатчики
--Приёмники
--Даты
DECLARE
  transiv_delet integer[];
  reciv_delete integer[]; 	
  date_reciv_delet timestamp without time zone[]; 
BEGIN
 
  transiv_delet = "Tepl"."fArr"($1); 
  reciv_delete  = "Tepl"."fArr"($2); 	
  date_reciv_delet = "Tepl"."farrTime"($3);

  DELETE FROM "Tepl"."IOT_reciver_cache"
     WHERE  (((reciver_num = ANY(reciv_delete)) or ($2=''))
	AND ((transiver_num = ANY(transiv_delet)) or ($1='') )
	AND (("IOT_reciver_cache".date_reciv = ANY(date_reciv_delet))  or ($3=''))  );

  return true;
end;$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."Clear_Iot_cache"(text, text, text)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."Clear_Iot_cache"(text, text, text) IS 'Очищает кэш согласно перечням в массивах
Пустой массив означает полную очитку по этому параметру';



-- Получение записей кэша
  

CREATE OR REPLACE FUNCTION "Tepl"."Get_IoT_reciver_cache"(transiv integer)
  RETURNS SETOF "Tepl"."IOT_reciver_cache" AS
$BODY$SELECT 	transiver_num,
	reciver_num, 
	date_reciv, 
	mess
  FROM "Tepl"."IOT_reciver_cache"
  where transiver_num = $1
  order by reciver_num, date_reciv$BODY$
  LANGUAGE sql VOLATILE
  COST 100
  ROWS 1000;
ALTER FUNCTION "Tepl"."Get_IoT_reciver_cache"(integer)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."Get_IoT_reciver_cache"(integer) IS 'Кэш приёмника по передатчику';


-- Удаление записей кэша при удлаении передатчика

CREATE OR REPLACE FUNCTION "Tepl"."DeleteDevice"(pdev_id text)
  RETURNS boolean AS
$BODY$
DECLARE
  dev "Tepl"."Device_cnt"%ROWTYPE;
  dev_ids INTEGER[]; 
  b boolean ;
  inf integer;
BEGIN
  dev_ids:="Tepl"."fArr"($1);
  /*Удаляем точки опроса использующие данный прибор*/
  Delete FROM "Tepl"."PointRead" Where "dev_id"=ANY(dev_ids);
  /*Удаляем свойства приборов*/
  Delete From "Tepl"."Device_Property" Where "dev_id"=ANY(dev_ids);

 /*Вычищаем из кэша приёмников данные этого прибора если он приёмник Iot */
  FOR dev in (SELECT * FROM "Tepl"."Device_cnt" 
		Where ("dev_id"=ANY(dev_ids)) AND("Tepl"."Device_cnt".dev_typ_id = 309))  Loop  	
     b = "Tepl"."Clear_Iot_cache"('', dev."Numbe", '');
  END Loop;

 /*Вычищаем из кэша приёмников данные этого прибора если он передатчик Iot */
  FOR dev in (SELECT * FROM "Tepl"."Device_cnt" dev
		Where "dev_id"=ANY(dev_ids) )  Loop  	
     inf = (select td."AdditionInfo" FROM "Tepl"."TypeDevices" td WHERE td.dev_typ_id = dev.dev_typ_id);
     if (inf & 1) = 1 then
	b = "Tepl"."Clear_Iot_cache"(dev."Numbe", '' ,'');
     end if;	
  END Loop;
   
  /*Удаляем сами приборы */
  Delete FROM "Tepl"."Device_cnt" Where "dev_id"=ANY(dev_ids);  
      
  return true;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."DeleteDevice"(text)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."DeleteDevice"(text) IS 'Удаление приборов,
а также точек чтения связанных с ними';

-- Удаление записей кэша при удлаении конфигурации соединения

CREATE OR REPLACE FUNCTION "Tepl"."DeleteConfigConnect"(pconf_id integer)
  RETURNS boolean AS
$BODY$
DECLARE
 dev "Tepl"."Device_cnt"%ROWTYPE;
 s BOOLEAN;
BEGIN
  /*Удаляем точки опроса для приборов и сами приборы  использующих конфигурацию*/
  FOR dev in SELECT * FROM "Tepl"."Device_cnt" Where ("Tepl"."Device_cnt"."Conf_id"=$1) Loop
    Delete From "Tepl"."PointRead" Where "dev_id"=dev."dev_id";
    --Delete From "Tepl"."Device_Property" Where "dev_id"=dev."dev_id";
    s = "Tepl"."DeleteDevice"(cast(dev."dev_id" as text) );
  END Loop;
  /*Удаляем приборы использующие конфигурацию*/   
 -- Delete FROM "Tepl"."Device_cnt"
 -- WHERE "Conf_id"=$1;
  /*Удаляем значения свойств конфигурации*/
  s:="Tepl"."DeletePropConfConnect"($1); 
  /*Удаляем саму конфигурацию*/
  Delete From "Tepl"."Connect_cnt_Config"
  Where "Conf_id"=$1;
  return true;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."DeleteConfigConnect"(integer)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."DeleteConfigConnect"(integer) IS 'Удаление конфигурации соединения';

-- Удаление записей кэша при изменении свойств передатчика

CREATE OR REPLACE FUNCTION "Tepl"."UpdateDevice"(pdev_id text, pdev_typ_id text, pconf_id text, pnumbe text, pcomment text, pplc_id text)
  RETURNS boolean AS
$BODY$
/*id редактируемого []*/
/*id типов приборов []*/
/*id конфигурации подключения []*/
/*номер прибора []*/
/*Комментарий прибра []*/
/*Место установки прибора []*/
DECLARE
  dev_ids INTEGER[];
  dev_typ_ids INTEGER[];
  Conf_ids INTEGER[];
  Numbes Text[];
  Comments Text[]; 
  plc_ids INTEGER[];  
  n INTEGER;
  i INTEGER;
  inf integer;   
  dev "Tepl"."Device_cnt"%ROWTYPE;      
  b boolean ;
BEGIN
 dev_typ_ids="Tepl"."fArr"($2);
 n:=array_upper(dev_typ_ids,1);
 if (n>0) THEN   
    dev_ids:="Tepl"."fArr"($1);
    Conf_ids:="Tepl"."fArr"($3);
    Numbes:="Tepl"."fArrText"($4);
    Comments:="Tepl"."fArrText"($5);    
    plc_ids:="Tepl"."fArr"($6);
    for i in 1..n Loop  	
       --Проверка на приёмник Iot
       for dev in (SELECT * FROM "Tepl"."Device_cnt"             --В этом цикле будет один оборот              
		     Where ("Tepl"."Device_cnt"."dev_id"= dev_ids[i]) AND
		           ("Tepl"."Device_cnt".dev_typ_id = 309)) loop		
	  if ( (cast (dev."Numbe" as integer)) <> (cast (Numbes[i] as integer))) then
	      -- Изменили номер приёмника , чистим кэш старого номера
	      b = "Tepl"."Clear_Iot_cache"('', dev."Numbe", '');	
	  end if; 	
       end loop;
       ------	
    
	/*Вычищаем из кэша приёмников данные этого прибора если он передатчик Iot */
	for dev in (SELECT * FROM "Tepl"."Device_cnt" Where "Tepl"."Device_cnt"."dev_id"= dev_ids[i]) loop
		inf = (select td."AdditionInfo" FROM "Tepl"."TypeDevices" td WHERE td.dev_typ_id = dev.dev_typ_id);
		if ((inf & 1) = 1)AND((cast (dev."Numbe" as integer)) <> (cast (Numbes[i] as integer))) then
			b = "Tepl"."Clear_Iot_cache"(dev."Numbe", '' ,'');
		end if;	
	end loop;

       UPDATE "Tepl"."Device_cnt"
       SET "dev_typ_id"=dev_typ_ids[i],
            "Conf_id"=Conf_ids[i],
            "Numbe"=Numbes[i],
            "Comment"=Comments[i],
            "plc_id"=plc_ids[i]
       WHERE
            "dev_id"=dev_ids[i];
    end Loop;    
 end if;     
 return true;

  return true;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."UpdateDevice"(text, text, text, text, text, text)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."UpdateDevice"(text, text, text, text, text, text) IS 'Изменение приборов установленных на объекте';

COMMENT ON COLUMN "Tepl"."TypeDevices"."AdditionInfo" IS 'Дополнительная инфа по прибору, побитно.
0 - Передатчик iot
7 - видимость прибора (по аналогии с параметром)';

-- Вставка записей кэша

CREATE OR REPLACE FUNCTION "Tepl"."Insert_Iot_cache"(transiv integer, reciv integer, date_reciv text, mes text)
  RETURNS boolean AS
$BODY$/*Номер передатчика*/
/*Номер приёмниуа*/
/*Даты приёма*/
/*Принятые данные*/
DECLARE
  i integer;
  n integer;  
  dates_transiv timestamp without time zone[];
  mes_datas Text[];
  
BEGIN

  dates_transiv="Tepl"."farrTime"($3);
  mes_datas = string_to_array($4,';');
  n:=array_upper(dates_transiv,1);  
  for i in 1..n Loop 
    INSERT INTO "Tepl"."IOT_reciver_cache"(
	transiver_num, reciver_num, date_reciv, mess)
	VALUES ($1, $2, dates_transiv[i], mes_datas[i]);
  end loop;
	
		
  return true;
END;$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."Insert_Iot_cache"(integer, integer, text, text)
  OWNER TO postgres;

-- Вставка записей кэша (только данные сообщения)

CREATE OR REPLACE FUNCTION "Tepl"."Insert_Iot_cache_message"(transiv integer, reciv integer, date_reciv text, mes text)
  RETURNS boolean AS
$BODY$
/*Номер передатчика*/
/*Номер приёмниуа*/
/*Даты приёма*/
/*Принятые данные*/
DECLARE
  i integer;
  n integer;  
  dates_transiv timestamp without time zone[];
  mes_datas Text[];
  
BEGIN

  dates_transiv="Tepl"."farrTime"($3);
  mes_datas = string_to_array($4,';');
  n:=array_upper(dates_transiv,1);  
  for i in 1..n Loop 
    UPDATE "Tepl"."IOT_reciver_cache"
    SET  mess = mes_datas[i]
    WHERE ("Tepl"."IOT_reciver_cache".transiver_num = $1) 
        AND ("Tepl"."IOT_reciver_cache".reciver_num = $2) 
        AND ("Tepl"."IOT_reciver_cache".date_reciv = dates_transiv[i]);
  end loop;
	
		
  return true;
END;$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION "Tepl"."Insert_Iot_cache_message"(integer, integer, text, text)
  OWNER TO postgres;
COMMENT ON FUNCTION "Tepl"."Insert_Iot_cache_message"(integer, integer, text, text) IS 'Заполняет сообщения для существующих в кэше дат';



