-- Sequence: "Tepl"."Journal_cnt_id_seq"

-- DROP SEQUENCE "Tepl"."Journal_cnt_id_seq";

CREATE SEQUENCE "Tepl"."Journal_cnt_id_seq"
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;


-- Table: "Tepl"."Journal_cnt"

-- DROP TABLE "Tepl"."Journal_cnt";

CREATE TABLE "Tepl"."Journal_cnt"
(
  id integer NOT NULL DEFAULT nextval('"Tepl"."Journal_cnt_id_seq"'::regclass),
  typ_jrn integer, -- Тип журнала
  name_jrn text, -- Название журнала
  pr_id integer NOT NULL, -- id параметра ресурса
  time_start timestamp without time zone, -- Время начала НС
  time_end timestamp without time zone, -- Время окончания НС
  "stringDesc" text, -- Описание события (текст)
  doubleDesc double precision -- Описание события (число)
  
)
WITH (
  OIDS=FALSE
);
COMMENT ON COLUMN "Tepl"."Journal_cnt".typ_jrn IS 'Тип журнала';
COMMENT ON COLUMN "Tepl"."Journal_cnt".Name_jrn IS 'Название журнала';
COMMENT ON COLUMN "Tepl"."Journal_cnt".pr_id IS 'id параметра ресурса';
COMMENT ON COLUMN "Tepl"."Journal_cnt".time_start IS 'Время начала НС';
COMMENT ON COLUMN "Tepl"."Journal_cnt".time_end IS 'Время окончания НС';
COMMENT ON COLUMN "Tepl"."Journal_cnt"."stringDesc" IS 'Описание события (текст)';
COMMENT ON COLUMN "Tepl"."Journal_cnt".doubleDesc IS 'Описание события (число)';

CREATE OR REPLACE FUNCTION "Tepl"."GetJournal"(ppr_id text, ptime_start timestamp without time zone, ptime_end timestamp without time zone)
  RETURNS SETOF "Tepl"."Journal_cnt" AS
$BODY$
DECLARE
  result "Tepl"."Journal_cnt";
BEGIN
  FOR result IN (
    SELECT *
    FROM "Tepl"."Journal_cnt"
    WHERE "pr_id" = CAST(ppr_id AS integer)
    AND "time_start" >= ptime_start
    AND "time_end" <= ptime_end
    ORDER BY "time_start"
  ) 
  LOOP
    RETURN NEXT result;
  END LOOP;
END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100
  ROWS 1000;



-- Function: "Tepl"."GetLastDataJrn"(integer, integer)

-- DROP FUNCTION "Tepl"."GetLastDataJrn"(integer, integer);

CREATE OR REPLACE FUNCTION "Tepl"."GetLastDataJrn"(ppr_id integer, ptyp_jrn integer)
  RETURNS timestamp without time zone AS
$BODY$
DECLARE
    last_end_date timestamp without time zone;
BEGIN
    SELECT MAX("Tepl"."Journal_cnt"."time_end")
    INTO last_end_date
    FROM "Tepl"."Journal_cnt"
    WHERE "Tepl"."Journal_cnt"."pr_id" = ppr_id
      AND "Tepl"."Journal_cnt"."typ_jrn" = ptyp_jrn;
    RETURN last_end_date;
END;
$BODY$
  LANGUAGE plpgsql;


-- Function: "Tepl"."InsertJournal"(integer, integer, timestamp without time zone, timestamp without time zone, integer, text, double precision, text)

-- DROP FUNCTION "Tepl"."InsertJournal"(integer, integer, timestamp without time zone, timestamp without time zone, integer, text, double precision, text);

CREATE OR REPLACE FUNCTION "Tepl"."InsertJournal"(ptyp_jrn integer, pname_jrn text, ppr_id integer, ptime_start timestamp without time zone, ptime_end timestamp without time zone, "stringDesc" text, pdoubledesc double precision)
  RETURNS void AS
$BODY$
insert into "Tepl"."Journal_cnt" ("typ_jrn", "name_jrn", "pr_id", "time_start", "time_end", "stringDesc", "doubledesc") Values ($1,$2,$3,$4,$5,$6,$7);
$BODY$
  LANGUAGE sql VOLATILE
  COST 100;